@@ -1,8 +1,8 @@
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 use sqlx_core::mssql::{Mssql, MssqlArguments};
 use sqlx_core::query::Query;
-use crate::DateTimeNative;
+use crate::{DateTimeNative, Uuid};
 use crate::error::Error;
 use crate::types::{DateNative, DateTimeUtc, DateUtc, Decimal, TimeNative, TimeUtc};
 
@@ -11,37 +11,42 @@ pub fn bind(t: Bson, mut q: Query<Mssql, MssqlArguments>) -> crate::Result<Query
     match t {
         Bson::String(s) => {
             if s.starts_with("DateTimeUtc(")  {
-                let data: DateTimeUtc = bson2::from_bson(Bson::String(s))?;
+                let data: DateTimeUtc = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("DateTimeNative(")  {
-                let data: DateTimeNative = bson2::from_bson(Bson::String(s))?;
+                let data: DateTimeNative = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("DateNative(") {
-                let data: DateNative = bson2::from_bson(Bson::String(s))?;
+                let data: DateNative = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("DateUtc(") {
-                let data: DateUtc = bson2::from_bson(Bson::String(s))?;
+                let data: DateUtc = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("TimeUtc(") {
-                let data: TimeUtc = bson2::from_bson(Bson::String(s))?;
+                let data: TimeUtc = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("TimeNative(") {
-                let data: TimeNative = bson2::from_bson(Bson::String(s))?;
+                let data: TimeNative = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
             if s.starts_with("Decimal(") {
-                let data: Decimal = bson2::from_bson(Bson::String(s))?;
+                let data: Decimal = rbson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner.to_string());
+                return Ok(q);
+            }
+            if s.starts_with("Uuid(") {
+                let data: Uuid = rbson::from_bson(Bson::String(s))?;
                 q = q.bind(data.inner.to_string());
                 return Ok(q);
             }
